@@ -4,7 +4,7 @@ import cadquery as cq
 
 from jupyter_cadquery.ocp_utils import loc_to_tq, tq_to_loc, serialize, deserialize
 from jupyter_cadquery.base import _tessellate_group, _combined_bb
-from jupyter_cadquery.cad_objects import to_assembly
+from jupyter_cadquery.cad_objects import to_assembly, PartGroup
 from jupyter_cadquery.utils import numpy_to_json
 
 try:
@@ -115,7 +115,10 @@ def load_binary(filename, assembly_name=None):
 
 
 def exportJson(cad_obj, filename):
-    shapes, states = _tessellate_group(to_assembly(cad_obj))
+    assembly = to_assembly(cad_obj)
+    if len(assembly.objects) == 1 and isinstance(assembly.objects[0], PartGroup):
+        assembly = assembly.objects[0]
+    shapes, states = _tessellate_group(assembly)
     bb = _combined_bb(shapes).to_dict()
     # add global bounding box
     shapes["bb"] = bb
